import React from 'react';
import { Button, Form, Row, Col, Card, Input, Modal, List } from 'antd';
import {
  DrawerForm,
  ProFormGroup,
  ProFormText,
  ProFormSelect,
  ProFormDigit,
  ProFormList
} from '@ant-design/pro-components';
import WangEditor from '@/components/Wangeditor';
import { postTaCheckItemQu, getTaCheckItemQu } from '@/service/tdlocquestion';
import { getTaCheckItemAn } from '@/service/tacheckiteman';

const QuItem = (props) => {
   const { qu, onEdit } = props;

   const quTitle = `${qu?.sortNo}. [${qu?.quType == 'fill' ? '填空' : '选择'}] ${qu?.title} (分值: ${qu?.computeType} ${qu?.anScore}/${qu?.maxScore})`

  return (
    <Card title={quTitle} extra={<Button type='link' onClick={onEdit}>修改</Button>} style={{marginTop: '24px'}}>
      <Card.Meta
        title={
          qu?.quType != 'fill' ?
          (
            <Row gutter={24}>
              {
                (qu?.answerList||[]).map((item) => {
                  const anStr = `${item.answerCode}. (${item.score || 0}分) ${item.answer}`;

                  return (
                    <Col span={12} key={item.answerId} style={{ height: '32px', lineHeight: '32px', fontWeight: 400 }}>
                    {anStr}
                    </Col>
                  );
                })
              }
            </Row>
          ) : null
        }
        description={(
          <>
            <h3>验收标准</h3>
            <div dangerouslySetInnerHTML={{ __html: qu?.stand }} />
          </>
        )}
      />
    </Card>
  );
}

export default React.forwardRef((props, ref) => {

  const { itemId, onChange } = props;
  
  const [open, setOpen] = React.useState(false);
  const [quInfo, setQuInfo] = React.useState(false);
  const [list, setList] = React.useState([]);
  // const [anList, setAnList] = React.useState([]);
  const [form] = Form.useForm();

  const onFinish = async (values) => {
    const data = { ...(quInfo || {}), ...values, itemId }
    const res = await postTaCheckItemQu(data);

    let found = false;
    const newList = list.map(item => {
      if (item.quId === res.quId) {
        found = true;
        return res;
      } else {
        return item
      }
    });

    if (!found) {
      newList.push(res);
    }

    setList(list);
    onChange(res);

    return true;
  }

  const onEditQu = (qu) => {
    setQuInfo(qu);
    setOpen(true);
  }

  React.useEffect(() => {
    if (quInfo) {
      form.setFieldsValue(quInfo);
    }
  }, [quInfo]);

  React.useEffect(() => {
    if (itemId) {
      getTaCheckItemQu({pageSize: 500, itemId}).then((res) => {
        setList(res.records);
      });
    }
  }, [itemId]);

  React.useImperativeHandle(ref, () => ({
    add: () => setOpen(true),
  }), []);

  return (
    <div>
      <DrawerForm title="问题维护" open={open} width={800} form={form} onFinish={onFinish} onOpenChange={setOpen}>
        <ProFormText
          name="title"
          label="题干描述"
          placeholder="请填写"
          rules={[
            {
              required: true,
              message: '请填写题干',
            },
          ]}
        />
        <Row gutter={24}>
          <Col span={12}>
            <ProFormSelect
              name="quType"
              label="问题类型"
              fieldProps={{
                style: { width: '100%' }
              }}
              valueEnum={{
                radio: '单选',
                fill: '填空'
              }}
              rules={[
                {
                  required: true,
                  message: '请选择问题类型',
                },
              ]}
            />
          </Col>
          <Col span={12}>
            <ProFormSelect
              name="computeType"
              label="计分方式"
              fieldProps={{
                style: { width: '100%' }
              }}
              valueEnum={{
                '+': '得分',
                '-': '扣分'
              }}
              rules={[
                {
                  required: true,
                  message: '请选择计分方式',
                },
              ]}
            />
          </Col>
        </Row>
        <Row gutter={24}>
          <Col span={12}>
            <ProFormDigit
              name="maxScore"
              label="最 高 分"
              min={0}
              fieldProps={{ precision: 2 }}
              rules={[
                {
                  required: true,
                  message: '请设置最高分',
                },
              ]}
            />
          </Col>
          <Col span={12}>
            <ProFormDigit
              name="anScore"
              label="单项计分"
              min={0}
              fieldProps={{ precision: 2 }}
              rules={[
                {
                  required: true,
                  message: '请设置单项计分',
                },
              ]}
            />
          </Col>
        </Row>
        <Form.Item name="stand" label="评分标准">
          <WangEditor
            height="200px"
            toolbarConfig={{
              toolbarKeys: [
                'headerSelect',
                'blockquote',
                '|',
                'bold',
                'underline',
                'italic',
                'color',
                'fontSize',
                '|',
                'bulletedList',
                'numberedList',
              ]
            }}
          />
        </Form.Item>
        <ProFormList
          name="answerList"
          label="选项列表"
          copyIconProps={false}
        >
          <Row gutter={24} style={{width: '730px'}}>
            <Col span={6}>
              <ProFormText
                name="answerCode"
                label="选项"
                help="类似 A, B, C, D"
              />
            </Col>
            <Col span={6}>
              <ProFormDigit
                name="score"
                label="计分"
                min={0}
                fieldProps={{ precision: 2 }}
              />
            </Col>
            <Col span={12}>
              <ProFormText
                name="answer"
                label="答案"
                placeholder="具体选项内容"
              />
            </Col>
          </Row>
        </ProFormList>
      </DrawerForm>
      <List
        itemLayout="horizontal"
        dataSource={list}
        renderItem={(item) => <QuItem qu={item} onEdit={() => onEditQu(item)}/>}
      />
    </div>
  )
});
