import React from 'react';
import { Button, Form, Row, Col, Card, List } from 'antd';
import {
  ProForm,
  ProFormText,
  ProFormSelect,
  ProFormList
} from '@ant-design/pro-components';
import { postTaCheckItemQu, getTaCheckItemQu } from '@/service/tdlocquestion';

const QuItem = (props) => {
  const { qu, onEdit } = props;

  const quTitle = `${qu?.sortNo}. [${qu?.quType == 'fill' ? '填空' : '选择'}] ${qu?.title}`

  return (
    <Card title={quTitle} extra={<Button type='link' onClick={onEdit}>修改</Button>} style={{ marginTop: '24px' }}>
      <Card.Meta
        title={
          qu?.quType != 'fill' ?
            (
              <Row gutter={24}>
                {
                  (qu || []).map((item) => {
                    const anStr = `${item.answerCode} ${item.answer}`;

                    return (
                      <Col span={12} key={item.answerId} style={{ height: '32px', lineHeight: '32px', fontWeight: 400 }}>
                        {anStr}
                      </Col>
                    );
                  })
                }
              </Row>
            ) : null
        }
        description={(
          <>
            <h3>验收标准</h3>
            <div dangerouslySetInnerHTML={{ __html: qu?.stand }} />
          </>
        )}
      />
    </Card>
  );
}

export default React.forwardRef((props, ref) => {

  const { itemId, onChange } = props;

  const [open, setOpen] = React.useState(false);
  const [quInfo, setQuInfo] = React.useState(false);
  const [list, setList] = React.useState([]);
  // const [anList, setAnList] = React.useState([]);
  const [form] = Form.useForm();

  const onFinish = async (values) => {
    const data = { ...(quInfo || {}), ...values, itemId }
    const res = await postTaCheckItemQu(data);

    console.log('方方data', data);
    console.log('方方res', res);
    let found = false;
    const newList = list.map(item => {
      if (item.quId === res.quId) {
        found = true;
        return res;
      } else {
        return item
      }
    });

    if (!found) {
      newList.push(res);
    }

    setList(list);
    onChange(res);

    return true;
  }

  const onEditQu = (qu) => {
    setQuInfo(qu);
    setOpen(true);
  }

  React.useEffect(() => {
    if (quInfo) {
      form.setFieldsValue(quInfo);
    }
  }, [quInfo]);

  React.useEffect(() => {
    if (itemId) {
      getTaCheckItemQu({ pageSize: 500, itemId }).then((res) => {
        setList(res.records);
      });
    }
  }, [itemId]);

  React.useImperativeHandle(ref, () => ({
    add: () => setOpen(true),
  }), []);

  return (
    <div>
      <ProForm title="问题维护" style={{ width: '800px' }} form={form} onFinish={onFinish}>
        <ProFormText
          name="title"
          label="问题描述"
          placeholder="请填写"
          rules={[
            {
              required: true,
              message: '请填写题干',
            },
          ]}
        />
        <ProFormSelect
          name="quType"
          label="问题类型"
          fieldProps={{
            style: { width: '100%' }
          }}
          valueEnum={{
            radio: '单选',
            fill: '填空'
          }}
          rules={[
            {
              required: true,
              message: '请选择问题类型',
            },
          ]}
        />
        <ProFormList
          label="选项列表"
          copyIconProps={false}
        >
          <Row gutter={24} style={{ width: '730px' }}>
            <Col span={6}>
              <ProFormText
                name="answerCode"
                label="选项"
                help="类似 A, B, C, D"
              />
            </Col>
            <Col span={6}>
              <ProFormText
                name="answer"
                label="答案"
                placeholder="具体选项内容"
              />
            </Col>
          </Row>
        </ProFormList>
      </ProForm>
      <List
        itemLayout="horizontal"
        dataSource={list}
        renderItem={(item) => <QuItem qu={item} onEdit={() => onEditQu(item)} />}
      />
    </div>
  )
});
